
# Slot: term

A generic slot for ontology terms

URI: [gocam:BiologicalProcessAssociation_term](https://w3id.org/gocam/BiologicalProcessAssociation_term)


## Domain and Range

[BiologicalProcessAssociation](BiologicalProcessAssociation.md) &#8594;  <sub>0..1</sub> [BiologicalProcessTermObject](BiologicalProcessTermObject.md)

## Parents

 *  is_a: [➞term](termAssociation__term.md)

## Children


## Used by

 * [BiologicalProcessAssociation](BiologicalProcessAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | gocam:term |
